parade.core package
===================

Submodules
----------

parade.core.context module
--------------------------

.. automodule:: parade.core.context
    :members:
    :undoc-members:
    :show-inheritance:

parade.core.engine module
-------------------------

.. automodule:: parade.core.engine
    :members:
    :undoc-members:
    :show-inheritance:

parade.core.recorder module
---------------------------

.. automodule:: parade.core.recorder
    :members:
    :undoc-members:
    :show-inheritance:

parade.core.task module
-----------------------

.. automodule:: parade.core.task
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.core
    :members:
    :undoc-members:
    :show-inheritance:
